# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmwasm/wasm/v1/authz.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from pyinjective.proto.cosmwasm.wasm.v1 import types_pb2 as cosmwasm_dot_wasm_dot_v1_dot_types__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x63osmwasm/wasm/v1/authz.proto\x12\x10\x63osmwasm.wasm.v1\x1a\x14gogoproto/gogo.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x1c\x63osmwasm/wasm/v1/types.proto\x1a\x19google/protobuf/any.proto\x1a\x11\x61mino/amino.proto\"\xa0\x01\n\x16StoreCodeAuthorization\x12>\n\x06grants\x18\x01 \x03(\x0b\x32\x1b.cosmwasm.wasm.v1.CodeGrantB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x06grants:F\xca\xb4-\"cosmos.authz.v1beta1.Authorization\x8a\xe7\xb0*\x1bwasm/StoreCodeAuthorization\"\xb4\x01\n\x1e\x43ontractExecutionAuthorization\x12\x42\n\x06grants\x18\x01 \x03(\x0b\x32\x1f.cosmwasm.wasm.v1.ContractGrantB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x06grants:N\xca\xb4-\"cosmos.authz.v1beta1.Authorization\x8a\xe7\xb0*#wasm/ContractExecutionAuthorization\"\xb4\x01\n\x1e\x43ontractMigrationAuthorization\x12\x42\n\x06grants\x18\x01 \x03(\x0b\x32\x1f.cosmwasm.wasm.v1.ContractGrantB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x06grants:N\xca\xb4-\"cosmos.authz.v1beta1.Authorization\x8a\xe7\xb0*#wasm/ContractMigrationAuthorization\"\x7f\n\tCodeGrant\x12\x1b\n\tcode_hash\x18\x01 \x01(\x0cR\x08\x63odeHash\x12U\n\x16instantiate_permission\x18\x02 \x01(\x0b\x32\x1e.cosmwasm.wasm.v1.AccessConfigR\x15instantiatePermission\"\xf4\x01\n\rContractGrant\x12\x34\n\x08\x63ontract\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x08\x63ontract\x12T\n\x05limit\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyB(\xca\xb4-$cosmwasm.wasm.v1.ContractAuthzLimitXR\x05limit\x12W\n\x06\x66ilter\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyB)\xca\xb4-%cosmwasm.wasm.v1.ContractAuthzFilterXR\x06\x66ilter\"n\n\rMaxCallsLimit\x12\x1c\n\tremaining\x18\x01 \x01(\x04R\tremaining:?\xca\xb4-$cosmwasm.wasm.v1.ContractAuthzLimitX\x8a\xe7\xb0*\x12wasm/MaxCallsLimit\"\xcd\x01\n\rMaxFundsLimit\x12{\n\x07\x61mounts\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBF\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x9a\xe7\xb0*\x0clegacy_coins\xa8\xe7\xb0*\x01R\x07\x61mounts:?\xca\xb4-$cosmwasm.wasm.v1.ContractAuthzLimitX\x8a\xe7\xb0*\x12wasm/MaxFundsLimit\"\xf6\x01\n\rCombinedLimit\x12\'\n\x0f\x63\x61lls_remaining\x18\x01 \x01(\x04R\x0e\x63\x61llsRemaining\x12{\n\x07\x61mounts\x18\x02 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBF\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x9a\xe7\xb0*\x0clegacy_coins\xa8\xe7\xb0*\x01R\x07\x61mounts:?\xca\xb4-$cosmwasm.wasm.v1.ContractAuthzLimitX\x8a\xe7\xb0*\x12wasm/CombinedLimit\"c\n\x16\x41llowAllMessagesFilter:I\xca\xb4-%cosmwasm.wasm.v1.ContractAuthzFilterX\x8a\xe7\xb0*\x1bwasm/AllowAllMessagesFilter\"}\n\x19\x41\x63\x63\x65ptedMessageKeysFilter\x12\x12\n\x04keys\x18\x01 \x03(\tR\x04keys:L\xca\xb4-%cosmwasm.wasm.v1.ContractAuthzFilterX\x8a\xe7\xb0*\x1ewasm/AcceptedMessageKeysFilter\"\xa7\x01\n\x16\x41\x63\x63\x65ptedMessagesFilter\x12\x42\n\x08messages\x18\x01 \x03(\x0c\x42&\xfa\xde\x1f\x12RawContractMessage\x9a\xe7\xb0*\x0binline_jsonR\x08messages:I\xca\xb4-%cosmwasm.wasm.v1.ContractAuthzFilterX\x8a\xe7\xb0*\x1bwasm/AcceptedMessagesFilterB\xb0\x01\n\x14\x63om.cosmwasm.wasm.v1B\nAuthzProtoP\x01Z&github.com/CosmWasm/wasmd/x/wasm/types\xa2\x02\x03\x43WX\xaa\x02\x10\x43osmwasm.Wasm.V1\xca\x02\x10\x43osmwasm\\Wasm\\V1\xe2\x02\x1c\x43osmwasm\\Wasm\\V1\\GPBMetadata\xea\x02\x12\x43osmwasm::Wasm::V1\xc8\xe1\x1e\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmwasm.wasm.v1.authz_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024com.cosmwasm.wasm.v1B\nAuthzProtoP\001Z&github.com/CosmWasm/wasmd/x/wasm/types\242\002\003CWX\252\002\020Cosmwasm.Wasm.V1\312\002\020Cosmwasm\\Wasm\\V1\342\002\034Cosmwasm\\Wasm\\V1\\GPBMetadata\352\002\022Cosmwasm::Wasm::V1\310\341\036\000'
  _globals['_STORECODEAUTHORIZATION'].fields_by_name['grants']._loaded_options = None
  _globals['_STORECODEAUTHORIZATION'].fields_by_name['grants']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_STORECODEAUTHORIZATION']._loaded_options = None
  _globals['_STORECODEAUTHORIZATION']._serialized_options = b'\312\264-\"cosmos.authz.v1beta1.Authorization\212\347\260*\033wasm/StoreCodeAuthorization'
  _globals['_CONTRACTEXECUTIONAUTHORIZATION'].fields_by_name['grants']._loaded_options = None
  _globals['_CONTRACTEXECUTIONAUTHORIZATION'].fields_by_name['grants']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_CONTRACTEXECUTIONAUTHORIZATION']._loaded_options = None
  _globals['_CONTRACTEXECUTIONAUTHORIZATION']._serialized_options = b'\312\264-\"cosmos.authz.v1beta1.Authorization\212\347\260*#wasm/ContractExecutionAuthorization'
  _globals['_CONTRACTMIGRATIONAUTHORIZATION'].fields_by_name['grants']._loaded_options = None
  _globals['_CONTRACTMIGRATIONAUTHORIZATION'].fields_by_name['grants']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_CONTRACTMIGRATIONAUTHORIZATION']._loaded_options = None
  _globals['_CONTRACTMIGRATIONAUTHORIZATION']._serialized_options = b'\312\264-\"cosmos.authz.v1beta1.Authorization\212\347\260*#wasm/ContractMigrationAuthorization'
  _globals['_CONTRACTGRANT'].fields_by_name['contract']._loaded_options = None
  _globals['_CONTRACTGRANT'].fields_by_name['contract']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_CONTRACTGRANT'].fields_by_name['limit']._loaded_options = None
  _globals['_CONTRACTGRANT'].fields_by_name['limit']._serialized_options = b'\312\264-$cosmwasm.wasm.v1.ContractAuthzLimitX'
  _globals['_CONTRACTGRANT'].fields_by_name['filter']._loaded_options = None
  _globals['_CONTRACTGRANT'].fields_by_name['filter']._serialized_options = b'\312\264-%cosmwasm.wasm.v1.ContractAuthzFilterX'
  _globals['_MAXCALLSLIMIT']._loaded_options = None
  _globals['_MAXCALLSLIMIT']._serialized_options = b'\312\264-$cosmwasm.wasm.v1.ContractAuthzLimitX\212\347\260*\022wasm/MaxCallsLimit'
  _globals['_MAXFUNDSLIMIT'].fields_by_name['amounts']._loaded_options = None
  _globals['_MAXFUNDSLIMIT'].fields_by_name['amounts']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\232\347\260*\014legacy_coins\250\347\260*\001'
  _globals['_MAXFUNDSLIMIT']._loaded_options = None
  _globals['_MAXFUNDSLIMIT']._serialized_options = b'\312\264-$cosmwasm.wasm.v1.ContractAuthzLimitX\212\347\260*\022wasm/MaxFundsLimit'
  _globals['_COMBINEDLIMIT'].fields_by_name['amounts']._loaded_options = None
  _globals['_COMBINEDLIMIT'].fields_by_name['amounts']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\232\347\260*\014legacy_coins\250\347\260*\001'
  _globals['_COMBINEDLIMIT']._loaded_options = None
  _globals['_COMBINEDLIMIT']._serialized_options = b'\312\264-$cosmwasm.wasm.v1.ContractAuthzLimitX\212\347\260*\022wasm/CombinedLimit'
  _globals['_ALLOWALLMESSAGESFILTER']._loaded_options = None
  _globals['_ALLOWALLMESSAGESFILTER']._serialized_options = b'\312\264-%cosmwasm.wasm.v1.ContractAuthzFilterX\212\347\260*\033wasm/AllowAllMessagesFilter'
  _globals['_ACCEPTEDMESSAGEKEYSFILTER']._loaded_options = None
  _globals['_ACCEPTEDMESSAGEKEYSFILTER']._serialized_options = b'\312\264-%cosmwasm.wasm.v1.ContractAuthzFilterX\212\347\260*\036wasm/AcceptedMessageKeysFilter'
  _globals['_ACCEPTEDMESSAGESFILTER'].fields_by_name['messages']._loaded_options = None
  _globals['_ACCEPTEDMESSAGESFILTER'].fields_by_name['messages']._serialized_options = b'\372\336\037\022RawContractMessage\232\347\260*\013inline_json'
  _globals['_ACCEPTEDMESSAGESFILTER']._loaded_options = None
  _globals['_ACCEPTEDMESSAGESFILTER']._serialized_options = b'\312\264-%cosmwasm.wasm.v1.ContractAuthzFilterX\212\347\260*\033wasm/AcceptedMessagesFilter'
  _globals['_STORECODEAUTHORIZATION']._serialized_start=208
  _globals['_STORECODEAUTHORIZATION']._serialized_end=368
  _globals['_CONTRACTEXECUTIONAUTHORIZATION']._serialized_start=371
  _globals['_CONTRACTEXECUTIONAUTHORIZATION']._serialized_end=551
  _globals['_CONTRACTMIGRATIONAUTHORIZATION']._serialized_start=554
  _globals['_CONTRACTMIGRATIONAUTHORIZATION']._serialized_end=734
  _globals['_CODEGRANT']._serialized_start=736
  _globals['_CODEGRANT']._serialized_end=863
  _globals['_CONTRACTGRANT']._serialized_start=866
  _globals['_CONTRACTGRANT']._serialized_end=1110
  _globals['_MAXCALLSLIMIT']._serialized_start=1112
  _globals['_MAXCALLSLIMIT']._serialized_end=1222
  _globals['_MAXFUNDSLIMIT']._serialized_start=1225
  _globals['_MAXFUNDSLIMIT']._serialized_end=1430
  _globals['_COMBINEDLIMIT']._serialized_start=1433
  _globals['_COMBINEDLIMIT']._serialized_end=1679
  _globals['_ALLOWALLMESSAGESFILTER']._serialized_start=1681
  _globals['_ALLOWALLMESSAGESFILTER']._serialized_end=1780
  _globals['_ACCEPTEDMESSAGEKEYSFILTER']._serialized_start=1782
  _globals['_ACCEPTEDMESSAGEKEYSFILTER']._serialized_end=1907
  _globals['_ACCEPTEDMESSAGESFILTER']._serialized_start=1910
  _globals['_ACCEPTEDMESSAGESFILTER']._serialized_end=2077
# @@protoc_insertion_point(module_scope)



from typing import Callable, Optional

from grpc.aio import Channel

from pyinjective.core.network import CookieAssistant
from pyinjective.proto.injective.stream.v1beta1 import query_pb2 as chain_stream_pb, query_pb2_grpc as chain_stream_grpc
from pyinjective.proto.injective.stream.v2 import (
    query_pb2 as chain_stream_v2_pb,
    query_pb2_grpc as chain_stream_v2_grpc,
)
from pyinjective.utils.grpc_api_stream_assistant import GrpcApiStreamAssistant


class ChainGrpcChainStream:
    def __init__(self, channel: Channel, cookie_assistant: CookieAssistant):
        self._stub = chain_stream_grpc.StreamStub(channel)
        self._stub_v2 = chain_stream_v2_grpc.StreamStub(channel)
        self._assistant = GrpcApiStreamAssistant(cookie_assistant=cookie_assistant)

    async def stream(
        self,
        callback: Callable,
        on_end_callback: Optional[Callable] = None,
        on_status_callback: Optional[Callable] = None,
        bank_balances_filter: Optional[chain_stream_pb.BankBalancesFilter] = None,
        subaccount_deposits_filter: Optional[chain_stream_pb.SubaccountDepositsFilter] = None,
        spot_trades_filter: Optional[chain_stream_pb.TradesFilter] = None,
        derivative_trades_filter: Optional[chain_stream_pb.TradesFilter] = None,
        spot_orders_filter: Optional[chain_stream_pb.OrdersFilter] = None,
        derivative_orders_filter: Optional[chain_stream_pb.OrdersFilter] = None,
        spot_orderbooks_filter: Optional[chain_stream_pb.OrderbookFilter] = None,
        derivative_orderbooks_filter: Optional[chain_stream_pb.OrderbookFilter] = None,
        positions_filter: Optional[chain_stream_pb.PositionsFilter] = None,
        oracle_price_filter: Optional[chain_stream_pb.OraclePriceFilter] = None,
    ):
        request = chain_stream_pb.StreamRequest(
            bank_balances_filter=bank_balances_filter,
            subaccount_deposits_filter=subaccount_deposits_filter,
            spot_trades_filter=spot_trades_filter,
            derivative_trades_filter=derivative_trades_filter,
            spot_orders_filter=spot_orders_filter,
            derivative_orders_filter=derivative_orders_filter,
            spot_orderbooks_filter=spot_orderbooks_filter,
            derivative_orderbooks_filter=derivative_orderbooks_filter,
            positions_filter=positions_filter,
            oracle_price_filter=oracle_price_filter,
        )

        await self._assistant.listen_stream(
            call=self._stub.Stream,
            request=request,
            callback=callback,
            on_end_callback=on_end_callback,
            on_status_callback=on_status_callback,
        )

    async def stream_v2(
        self,
        callback: Callable,
        on_end_callback: Optional[Callable] = None,
        on_status_callback: Optional[Callable] = None,
        bank_balances_filter: Optional[chain_stream_v2_pb.BankBalancesFilter] = None,
        subaccount_deposits_filter: Optional[chain_stream_v2_pb.SubaccountDepositsFilter] = None,
        spot_trades_filter: Optional[chain_stream_v2_pb.TradesFilter] = None,
        derivative_trades_filter: Optional[chain_stream_v2_pb.TradesFilter] = None,
        spot_orders_filter: Optional[chain_stream_v2_pb.OrdersFilter] = None,
        derivative_orders_filter: Optional[chain_stream_v2_pb.OrdersFilter] = None,
        spot_orderbooks_filter: Optional[chain_stream_v2_pb.OrderbookFilter] = None,
        derivative_orderbooks_filter: Optional[chain_stream_v2_pb.OrderbookFilter] = None,
        positions_filter: Optional[chain_stream_v2_pb.PositionsFilter] = None,
        oracle_price_filter: Optional[chain_stream_v2_pb.OraclePriceFilter] = None,
    ):
        request = chain_stream_v2_pb.StreamRequest(
            bank_balances_filter=bank_balances_filter,
            subaccount_deposits_filter=subaccount_deposits_filter,
            spot_trades_filter=spot_trades_filter,
            derivative_trades_filter=derivative_trades_filter,
            spot_orders_filter=spot_orders_filter,
            derivative_orders_filter=derivative_orders_filter,
            spot_orderbooks_filter=spot_orderbooks_filter,
            derivative_orderbooks_filter=derivative_orderbooks_filter,
            positions_filter=positions_filter,
            oracle_price_filter=oracle_price_filter,
        )

        await self._assistant.listen_stream(
            call=self._stub_v2.StreamV2,
            request=request,
            callback=callback,
            on_end_callback=on_end_callback,
            on_status_callback=on_status_callback,
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cometbft/crypto/v1/proof.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x63ometbft/crypto/v1/proof.proto\x12\x12\x63ometbft.crypto.v1\x1a\x14gogoproto/gogo.proto\"f\n\x05Proof\x12\x14\n\x05total\x18\x01 \x01(\x03R\x05total\x12\x14\n\x05index\x18\x02 \x01(\x03R\x05index\x12\x1b\n\tleaf_hash\x18\x03 \x01(\x0cR\x08leafHash\x12\x14\n\x05\x61unts\x18\x04 \x03(\x0cR\x05\x61unts\"L\n\x07ValueOp\x12\x10\n\x03key\x18\x01 \x01(\x0cR\x03key\x12/\n\x05proof\x18\x02 \x01(\x0b\x32\x19.cometbft.crypto.v1.ProofR\x05proof\"J\n\x08\x44ominoOp\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05input\x18\x02 \x01(\tR\x05input\x12\x16\n\x06output\x18\x03 \x01(\tR\x06output\"C\n\x07ProofOp\x12\x12\n\x04type\x18\x01 \x01(\tR\x04type\x12\x10\n\x03key\x18\x02 \x01(\x0cR\x03key\x12\x12\n\x04\x64\x61ta\x18\x03 \x01(\x0cR\x04\x64\x61ta\"?\n\x08ProofOps\x12\x33\n\x03ops\x18\x01 \x03(\x0b\x32\x1b.cometbft.crypto.v1.ProofOpB\x04\xc8\xde\x1f\x00R\x03opsB\xc3\x01\n\x16\x63om.cometbft.crypto.v1B\nProofProtoP\x01Z3github.com/cometbft/cometbft/api/cometbft/crypto/v1\xa2\x02\x03\x43\x43X\xaa\x02\x12\x43ometbft.Crypto.V1\xca\x02\x12\x43ometbft\\Crypto\\V1\xe2\x02\x1e\x43ometbft\\Crypto\\V1\\GPBMetadata\xea\x02\x14\x43ometbft::Crypto::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.crypto.v1.proof_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.cometbft.crypto.v1B\nProofProtoP\001Z3github.com/cometbft/cometbft/api/cometbft/crypto/v1\242\002\003CCX\252\002\022Cometbft.Crypto.V1\312\002\022Cometbft\\Crypto\\V1\342\002\036Cometbft\\Crypto\\V1\\GPBMetadata\352\002\024Cometbft::Crypto::V1'
  _globals['_PROOFOPS'].fields_by_name['ops']._loaded_options = None
  _globals['_PROOFOPS'].fields_by_name['ops']._serialized_options = b'\310\336\037\000'
  _globals['_PROOF']._serialized_start=76
  _globals['_PROOF']._serialized_end=178
  _globals['_VALUEOP']._serialized_start=180
  _globals['_VALUEOP']._serialized_end=256
  _globals['_DOMINOOP']._serialized_start=258
  _globals['_DOMINOOP']._serialized_end=332
  _globals['_PROOFOP']._serialized_start=334
  _globals['_PROOFOP']._serialized_end=401
  _globals['_PROOFOPS']._serialized_start=403
  _globals['_PROOFOPS']._serialized_end=466
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/oracle/v1beta1/events.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from pyinjective.proto.injective.oracle.v1beta1 import oracle_pb2 as injective_dot_oracle_dot_v1beta1_dot_oracle__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%injective/oracle/v1beta1/events.proto\x12\x18injective.oracle.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a%injective/oracle/v1beta1/oracle.proto\"\x8c\x01\n\x16SetChainlinkPriceEvent\x12\x17\n\x07\x66\x65\x65\x64_id\x18\x01 \x01(\tR\x06\x66\x65\x65\x64Id\x12;\n\x06\x61nswer\x18\x02 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x06\x61nswer\x12\x1c\n\ttimestamp\x18\x03 \x01(\x04R\ttimestamp\"\xc2\x01\n\x11SetBandPriceEvent\x12\x18\n\x07relayer\x18\x01 \x01(\tR\x07relayer\x12\x16\n\x06symbol\x18\x02 \x01(\tR\x06symbol\x12\x39\n\x05price\x18\x03 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x05price\x12!\n\x0cresolve_time\x18\x04 \x01(\x04R\x0bresolveTime\x12\x1d\n\nrequest_id\x18\x05 \x01(\x04R\trequestId\"\xe6\x01\n\x14SetBandIBCPriceEvent\x12\x18\n\x07relayer\x18\x01 \x01(\tR\x07relayer\x12\x18\n\x07symbols\x18\x02 \x03(\tR\x07symbols\x12;\n\x06prices\x18\x03 \x03(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x06prices\x12!\n\x0cresolve_time\x18\x04 \x01(\x04R\x0bresolveTime\x12\x1d\n\nrequest_id\x18\x05 \x01(\x04R\trequestId\x12\x1b\n\tclient_id\x18\x06 \x01(\x03R\x08\x63lientId\"T\n\x16\x45ventBandIBCAckSuccess\x12\x1d\n\nack_result\x18\x01 \x01(\tR\tackResult\x12\x1b\n\tclient_id\x18\x02 \x01(\x03R\x08\x63lientId\"P\n\x14\x45ventBandIBCAckError\x12\x1b\n\tack_error\x18\x01 \x01(\tR\x08\x61\x63kError\x12\x1b\n\tclient_id\x18\x02 \x01(\x03R\x08\x63lientId\":\n\x1b\x45ventBandIBCResponseTimeout\x12\x1b\n\tclient_id\x18\x01 \x01(\x03R\x08\x63lientId\"\x97\x01\n\x16SetPriceFeedPriceEvent\x12\x18\n\x07relayer\x18\x01 \x01(\tR\x07relayer\x12\x12\n\x04\x62\x61se\x18\x02 \x01(\tR\x04\x62\x61se\x12\x14\n\x05quote\x18\x03 \x01(\tR\x05quote\x12\x39\n\x05price\x18\x04 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x05price\"\xa0\x01\n\x15SetProviderPriceEvent\x12\x1a\n\x08provider\x18\x01 \x01(\tR\x08provider\x12\x18\n\x07relayer\x18\x02 \x01(\tR\x07relayer\x12\x16\n\x06symbol\x18\x03 \x01(\tR\x06symbol\x12\x39\n\x05price\x18\x04 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x05price\"\x88\x01\n\x15SetCoinbasePriceEvent\x12\x16\n\x06symbol\x18\x01 \x01(\tR\x06symbol\x12\x39\n\x05price\x18\x02 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x05price\x12\x1c\n\ttimestamp\x18\x03 \x01(\x04R\ttimestamp\"X\n\x13\x45ventSetStorkPrices\x12\x41\n\x06prices\x18\x01 \x03(\x0b\x32).injective.oracle.v1beta1.StorkPriceStateR\x06prices\"V\n\x12\x45ventSetPythPrices\x12@\n\x06prices\x18\x01 \x03(\x0b\x32(.injective.oracle.v1beta1.PythPriceStateR\x06pricesB\xfb\x01\n\x1c\x63om.injective.oracle.v1beta1B\x0b\x45ventsProtoP\x01ZLgithub.com/InjectiveLabs/injective-core/injective-chain/modules/oracle/types\xa2\x02\x03IOX\xaa\x02\x18Injective.Oracle.V1beta1\xca\x02\x18Injective\\Oracle\\V1beta1\xe2\x02$Injective\\Oracle\\V1beta1\\GPBMetadata\xea\x02\x1aInjective::Oracle::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.oracle.v1beta1.events_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034com.injective.oracle.v1beta1B\013EventsProtoP\001ZLgithub.com/InjectiveLabs/injective-core/injective-chain/modules/oracle/types\242\002\003IOX\252\002\030Injective.Oracle.V1beta1\312\002\030Injective\\Oracle\\V1beta1\342\002$Injective\\Oracle\\V1beta1\\GPBMetadata\352\002\032Injective::Oracle::V1beta1'
  _globals['_SETCHAINLINKPRICEEVENT'].fields_by_name['answer']._loaded_options = None
  _globals['_SETCHAINLINKPRICEEVENT'].fields_by_name['answer']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_SETBANDPRICEEVENT'].fields_by_name['price']._loaded_options = None
  _globals['_SETBANDPRICEEVENT'].fields_by_name['price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_SETBANDIBCPRICEEVENT'].fields_by_name['prices']._loaded_options = None
  _globals['_SETBANDIBCPRICEEVENT'].fields_by_name['prices']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_SETPRICEFEEDPRICEEVENT'].fields_by_name['price']._loaded_options = None
  _globals['_SETPRICEFEEDPRICEEVENT'].fields_by_name['price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_SETPROVIDERPRICEEVENT'].fields_by_name['price']._loaded_options = None
  _globals['_SETPROVIDERPRICEEVENT'].fields_by_name['price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_SETCOINBASEPRICEEVENT'].fields_by_name['price']._loaded_options = None
  _globals['_SETCOINBASEPRICEEVENT'].fields_by_name['price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_SETCHAINLINKPRICEEVENT']._serialized_start=161
  _globals['_SETCHAINLINKPRICEEVENT']._serialized_end=301
  _globals['_SETBANDPRICEEVENT']._serialized_start=304
  _globals['_SETBANDPRICEEVENT']._serialized_end=498
  _globals['_SETBANDIBCPRICEEVENT']._serialized_start=501
  _globals['_SETBANDIBCPRICEEVENT']._serialized_end=731
  _globals['_EVENTBANDIBCACKSUCCESS']._serialized_start=733
  _globals['_EVENTBANDIBCACKSUCCESS']._serialized_end=817
  _globals['_EVENTBANDIBCACKERROR']._serialized_start=819
  _globals['_EVENTBANDIBCACKERROR']._serialized_end=899
  _globals['_EVENTBANDIBCRESPONSETIMEOUT']._serialized_start=901
  _globals['_EVENTBANDIBCRESPONSETIMEOUT']._serialized_end=959
  _globals['_SETPRICEFEEDPRICEEVENT']._serialized_start=962
  _globals['_SETPRICEFEEDPRICEEVENT']._serialized_end=1113
  _globals['_SETPROVIDERPRICEEVENT']._serialized_start=1116
  _globals['_SETPROVIDERPRICEEVENT']._serialized_end=1276
  _globals['_SETCOINBASEPRICEEVENT']._serialized_start=1279
  _globals['_SETCOINBASEPRICEEVENT']._serialized_end=1415
  _globals['_EVENTSETSTORKPRICES']._serialized_start=1417
  _globals['_EVENTSETSTORKPRICES']._serialized_end=1505
  _globals['_EVENTSETPYTHPRICES']._serialized_start=1507
  _globals['_EVENTSETPYTHPRICES']._serialized_end=1593
# @@protoc_insertion_point(module_scope)



from typing import Any, Callable, Dict, List, Optional

from grpc import Channel

from pyinjective.client.model.pagination import PaginationOption
from pyinjective.core.network import CookieAssistant
from pyinjective.proto.ibc.core.channel.v1 import (
    query_pb2 as ibc_channel_query,
    query_pb2_grpc as ibc_channel_query_grpc,
)
from pyinjective.utils.grpc_api_request_assistant import GrpcApiRequestAssistant


class IBCChannelGrpcApi:
    def __init__(self, channel: Channel, cookie_assistant: CookieAssistant):
        self._stub = ibc_channel_query_grpc.QueryStub(channel)
        self._assistant = GrpcApiRequestAssistant(cookie_assistant=cookie_assistant)

    async def fetch_channel(self, port_id: str, channel_id: str) -> Dict[str, Any]:
        request = ibc_channel_query.QueryChannelRequest(port_id=port_id, channel_id=channel_id)
        response = await self._execute_call(call=self._stub.Channel, request=request)

        return response

    async def fetch_channels(self, pagination: Optional[PaginationOption] = None) -> Dict[str, Any]:
        if pagination is None:
            pagination = PaginationOption()
        request = ibc_channel_query.QueryChannelsRequest(pagination=pagination.create_pagination_request())
        response = await self._execute_call(call=self._stub.Channels, request=request)

        return response

    async def fetch_connection_channels(
        self, connection: str, pagination: Optional[PaginationOption] = None
    ) -> Dict[str, Any]:
        if pagination is None:
            pagination = PaginationOption()
        request = ibc_channel_query.QueryConnectionChannelsRequest(
            connection=connection, pagination=pagination.create_pagination_request()
        )
        response = await self._execute_call(call=self._stub.ConnectionChannels, request=request)

        return response

    async def fetch_channel_client_state(
        self,
        port_id: str,
        channel_id: str,
    ) -> Dict[str, Any]:
        request = ibc_channel_query.QueryChannelClientStateRequest(
            port_id=port_id,
            channel_id=channel_id,
        )
        response = await self._execute_call(call=self._stub.ChannelClientState, request=request)

        return response

    async def fetch_channel_consensus_state(
        self,
        port_id: str,
        channel_id: str,
        revision_number: int,
        revision_height: int,
    ) -> Dict[str, Any]:
        request = ibc_channel_query.QueryChannelConsensusStateRequest(
            port_id=port_id,
            channel_id=channel_id,
            revision_number=revision_number,
            revision_height=revision_height,
        )
        response = await self._execute_call(call=self._stub.ChannelConsensusState, request=request)

        return response

    async def fetch_packet_commitment(
        self,
        port_id: str,
        channel_id: str,
        sequence: int,
    ) -> Dict[str, Any]:
        request = ibc_channel_query.QueryPacketCommitmentRequest(
            port_id=port_id,
            channel_id=channel_id,
            sequence=sequence,
        )
        response = await self._execute_call(call=self._stub.PacketCommitment, request=request)

        return response

    async def fetch_packet_commitments(
        self, port_id: str, channel_id: str, pagination: Optional[PaginationOption] = None
    ) -> Dict[str, Any]:
        if pagination is None:
            pagination = PaginationOption()
        request = ibc_channel_query.QueryPacketCommitmentsRequest(
            port_id=port_id, channel_id=channel_id, pagination=pagination.create_pagination_request()
        )
        response = await self._execute_call(call=self._stub.PacketCommitments, request=request)

        return response

    async def fetch_packet_receipt(self, port_id: str, channel_id: str, sequence: int) -> Dict[str, Any]:
        request = ibc_channel_query.QueryPacketReceiptRequest(port_id=port_id, channel_id=channel_id, sequence=sequence)
        response = await self._execute_call(call=self._stub.PacketReceipt, request=request)

        return response

    async def fetch_packet_acknowledgement(self, port_id: str, channel_id: str, sequence: int) -> Dict[str, Any]:
        request = ibc_channel_query.QueryPacketAcknowledgementRequest(
            port_id=port_id, channel_id=channel_id, sequence=sequence
        )
        response = await self._execute_call(call=self._stub.PacketAcknowledgement, request=request)

        return response

    async def fetch_packet_acknowledgements(
        self,
        port_id: str,
        channel_id: str,
        packet_commitment_sequences: Optional[List[int]] = None,
        pagination: Optional[PaginationOption] = None,
    ) -> Dict[str, Any]:
        if pagination is None:
            pagination = PaginationOption()

        request = ibc_channel_query.QueryPacketAcknowledgementsRequest(
            port_id=port_id,
            channel_id=channel_id,
            packet_commitment_sequences=packet_commitment_sequences,
            pagination=pagination.create_pagination_request(),
        )
        response = await self._execute_call(call=self._stub.PacketAcknowledgements, request=request)

        return response

    async def fetch_unreceived_packets(
        self, port_id: str, channel_id: str, packet_commitment_sequences: Optional[List[int]] = None
    ) -> Dict[str, Any]:
        request = ibc_channel_query.QueryUnreceivedPacketsRequest(
            port_id=port_id,
            channel_id=channel_id,
            packet_commitment_sequences=packet_commitment_sequences,
        )
        response = await self._execute_call(call=self._stub.UnreceivedPackets, request=request)

        return response

    async def fetch_unreceived_acks(
        self, port_id: str, channel_id: str, packet_ack_sequences: Optional[List[int]] = None
    ) -> Dict[str, Any]:
        request = ibc_channel_query.QueryUnreceivedAcksRequest(
            port_id=port_id,
            channel_id=channel_id,
            packet_ack_sequences=packet_ack_sequences,
        )
        response = await self._execute_call(call=self._stub.UnreceivedAcks, request=request)

        return response

    async def fetch_next_sequence_receive(self, port_id: str, channel_id: str) -> Dict[str, Any]:
        request = ibc_channel_query.QueryNextSequenceReceiveRequest(
            port_id=port_id,
            channel_id=channel_id,
        )
        response = await self._execute_call(call=self._stub.NextSequenceReceive, request=request)

        return response

    async def _execute_call(self, call: Callable, request) -> Dict[str, Any]:
        return await self._assistant.execute_call(call=call, request=request)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/insurance/v1beta1/insurance.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from pyinjective.proto.injective.oracle.v1beta1 import oracle_pb2 as injective_dot_oracle_dot_v1beta1_dot_oracle__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+injective/insurance/v1beta1/insurance.proto\x12\x1binjective.insurance.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a%injective/oracle/v1beta1/oracle.proto\x1a\x11\x61mino/amino.proto\"\xd7\x01\n\x06Params\x12\xb1\x01\n)default_redemption_notice_period_duration\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB<\xc8\xde\x1f\x00\xf2\xde\x1f\x30yaml:\"default_redemption_notice_period_duration\"\x98\xdf\x1f\x01R%defaultRedemptionNoticePeriodDuration:\x19\xe8\xa0\x1f\x01\x8a\xe7\xb0*\x10insurance/Params\"\xec\x04\n\rInsuranceFund\x12#\n\rdeposit_denom\x18\x01 \x01(\tR\x0c\x64\x65positDenom\x12;\n\x1ainsurance_pool_token_denom\x18\x02 \x01(\tR\x17insurancePoolTokenDenom\x12\x9a\x01\n!redemption_notice_period_duration\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB4\xc8\xde\x1f\x00\xf2\xde\x1f(yaml:\"redemption_notice_period_duration\"\x98\xdf\x1f\x01R\x1eredemptionNoticePeriodDuration\x12\x37\n\x07\x62\x61lance\x18\x04 \x01(\tB\x1d\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.IntR\x07\x62\x61lance\x12>\n\x0btotal_share\x18\x05 \x01(\tB\x1d\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.IntR\ntotalShare\x12\x1b\n\tmarket_id\x18\x06 \x01(\tR\x08marketId\x12#\n\rmarket_ticker\x18\x07 \x01(\tR\x0cmarketTicker\x12\x1f\n\x0boracle_base\x18\x08 \x01(\tR\noracleBase\x12!\n\x0coracle_quote\x18\t \x01(\tR\x0boracleQuote\x12\x45\n\x0boracle_type\x18\n \x01(\x0e\x32$.injective.oracle.v1beta1.OracleTypeR\noracleType\x12\x16\n\x06\x65xpiry\x18\x0b \x01(\x03R\x06\x65xpiry\"\xb1\x02\n\x12RedemptionSchedule\x12\x0e\n\x02id\x18\x01 \x01(\x04R\x02id\x12\x1a\n\x08marketId\x18\x02 \x01(\tR\x08marketId\x12\x1a\n\x08redeemer\x18\x03 \x01(\tR\x08redeemer\x12\x84\x01\n\x19\x63laimable_redemption_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB,\xc8\xde\x1f\x00\xf2\xde\x1f yaml:\"claimable_redemption_time\"\x90\xdf\x1f\x01R\x17\x63laimableRedemptionTime\x12L\n\x11redemption_amount\x18\x05 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00R\x10redemptionAmountB\x90\x02\n\x1f\x63om.injective.insurance.v1beta1B\x0eInsuranceProtoP\x01ZOgithub.com/InjectiveLabs/injective-core/injective-chain/modules/insurance/types\xa2\x02\x03IIX\xaa\x02\x1bInjective.Insurance.V1beta1\xca\x02\x1bInjective\\Insurance\\V1beta1\xe2\x02\'Injective\\Insurance\\V1beta1\\GPBMetadata\xea\x02\x1dInjective::Insurance::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.insurance.v1beta1.insurance_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\037com.injective.insurance.v1beta1B\016InsuranceProtoP\001ZOgithub.com/InjectiveLabs/injective-core/injective-chain/modules/insurance/types\242\002\003IIX\252\002\033Injective.Insurance.V1beta1\312\002\033Injective\\Insurance\\V1beta1\342\002\'Injective\\Insurance\\V1beta1\\GPBMetadata\352\002\035Injective::Insurance::V1beta1'
  _globals['_PARAMS'].fields_by_name['default_redemption_notice_period_duration']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['default_redemption_notice_period_duration']._serialized_options = b'\310\336\037\000\362\336\0370yaml:\"default_redemption_notice_period_duration\"\230\337\037\001'
  _globals['_PARAMS']._loaded_options = None
  _globals['_PARAMS']._serialized_options = b'\350\240\037\001\212\347\260*\020insurance/Params'
  _globals['_INSURANCEFUND'].fields_by_name['redemption_notice_period_duration']._loaded_options = None
  _globals['_INSURANCEFUND'].fields_by_name['redemption_notice_period_duration']._serialized_options = b'\310\336\037\000\362\336\037(yaml:\"redemption_notice_period_duration\"\230\337\037\001'
  _globals['_INSURANCEFUND'].fields_by_name['balance']._loaded_options = None
  _globals['_INSURANCEFUND'].fields_by_name['balance']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int'
  _globals['_INSURANCEFUND'].fields_by_name['total_share']._loaded_options = None
  _globals['_INSURANCEFUND'].fields_by_name['total_share']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int'
  _globals['_REDEMPTIONSCHEDULE'].fields_by_name['claimable_redemption_time']._loaded_options = None
  _globals['_REDEMPTIONSCHEDULE'].fields_by_name['claimable_redemption_time']._serialized_options = b'\310\336\037\000\362\336\037 yaml:\"claimable_redemption_time\"\220\337\037\001'
  _globals['_REDEMPTIONSCHEDULE'].fields_by_name['redemption_amount']._loaded_options = None
  _globals['_REDEMPTIONSCHEDULE'].fields_by_name['redemption_amount']._serialized_options = b'\310\336\037\000'
  _globals['_PARAMS']._serialized_start=254
  _globals['_PARAMS']._serialized_end=469
  _globals['_INSURANCEFUND']._serialized_start=472
  _globals['_INSURANCEFUND']._serialized_end=1092
  _globals['_REDEMPTIONSCHEDULE']._serialized_start=1095
  _globals['_REDEMPTIONSCHEDULE']._serialized_end=1400
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/oracle/v1beta1/genesis.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.injective.oracle.v1beta1 import oracle_pb2 as injective_dot_oracle_dot_v1beta1_dot_oracle__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&injective/oracle/v1beta1/genesis.proto\x12\x18injective.oracle.v1beta1\x1a%injective/oracle/v1beta1/oracle.proto\x1a\x14gogoproto/gogo.proto\"\xe4\n\n\x0cGenesisState\x12>\n\x06params\x18\x01 \x01(\x0b\x32 .injective.oracle.v1beta1.ParamsB\x04\xc8\xde\x1f\x00R\x06params\x12#\n\rband_relayers\x18\x02 \x03(\tR\x0c\x62\x61ndRelayers\x12T\n\x11\x62\x61nd_price_states\x18\x03 \x03(\x0b\x32(.injective.oracle.v1beta1.BandPriceStateR\x0f\x62\x61ndPriceStates\x12_\n\x17price_feed_price_states\x18\x04 \x03(\x0b\x32(.injective.oracle.v1beta1.PriceFeedStateR\x14priceFeedPriceStates\x12`\n\x15\x63oinbase_price_states\x18\x05 \x03(\x0b\x32,.injective.oracle.v1beta1.CoinbasePriceStateR\x13\x63oinbasePriceStates\x12[\n\x15\x62\x61nd_ibc_price_states\x18\x06 \x03(\x0b\x32(.injective.oracle.v1beta1.BandPriceStateR\x12\x62\x61ndIbcPriceStates\x12\x64\n\x18\x62\x61nd_ibc_oracle_requests\x18\x07 \x03(\x0b\x32+.injective.oracle.v1beta1.BandOracleRequestR\x15\x62\x61ndIbcOracleRequests\x12U\n\x0f\x62\x61nd_ibc_params\x18\x08 \x01(\x0b\x32\'.injective.oracle.v1beta1.BandIBCParamsB\x04\xc8\xde\x1f\x00R\rbandIbcParams\x12\x38\n\x19\x62\x61nd_ibc_latest_client_id\x18\t \x01(\x04R\x15\x62\x61ndIbcLatestClientId\x12S\n\x10\x63\x61lldata_records\x18\n \x03(\x0b\x32(.injective.oracle.v1beta1.CalldataRecordR\x0f\x63\x61lldataRecords\x12:\n\x1a\x62\x61nd_ibc_latest_request_id\x18\x0b \x01(\x04R\x16\x62\x61ndIbcLatestRequestId\x12\x63\n\x16\x63hainlink_price_states\x18\x0c \x03(\x0b\x32-.injective.oracle.v1beta1.ChainlinkPriceStateR\x14\x63hainlinkPriceStates\x12`\n\x18historical_price_records\x18\r \x03(\x0b\x32&.injective.oracle.v1beta1.PriceRecordsR\x16historicalPriceRecords\x12P\n\x0fprovider_states\x18\x0e \x03(\x0b\x32\'.injective.oracle.v1beta1.ProviderStateR\x0eproviderStates\x12T\n\x11pyth_price_states\x18\x0f \x03(\x0b\x32(.injective.oracle.v1beta1.PythPriceStateR\x0fpythPriceStates\x12W\n\x12stork_price_states\x18\x10 \x03(\x0b\x32).injective.oracle.v1beta1.StorkPriceStateR\x10storkPriceStates\x12)\n\x10stork_publishers\x18\x11 \x03(\tR\x0fstorkPublishers\"I\n\x0e\x43\x61lldataRecord\x12\x1b\n\tclient_id\x18\x01 \x01(\x04R\x08\x63lientId\x12\x1a\n\x08\x63\x61lldata\x18\x02 \x01(\x0cR\x08\x63\x61lldataB\xfc\x01\n\x1c\x63om.injective.oracle.v1beta1B\x0cGenesisProtoP\x01ZLgithub.com/InjectiveLabs/injective-core/injective-chain/modules/oracle/types\xa2\x02\x03IOX\xaa\x02\x18Injective.Oracle.V1beta1\xca\x02\x18Injective\\Oracle\\V1beta1\xe2\x02$Injective\\Oracle\\V1beta1\\GPBMetadata\xea\x02\x1aInjective::Oracle::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.oracle.v1beta1.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034com.injective.oracle.v1beta1B\014GenesisProtoP\001ZLgithub.com/InjectiveLabs/injective-core/injective-chain/modules/oracle/types\242\002\003IOX\252\002\030Injective.Oracle.V1beta1\312\002\030Injective\\Oracle\\V1beta1\342\002$Injective\\Oracle\\V1beta1\\GPBMetadata\352\002\032Injective::Oracle::V1beta1'
  _globals['_GENESISSTATE'].fields_by_name['params']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['band_ibc_params']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['band_ibc_params']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE']._serialized_start=130
  _globals['_GENESISSTATE']._serialized_end=1510
  _globals['_CALLDATARECORD']._serialized_start=1512
  _globals['_CALLDATARECORD']._serialized_end=1585
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from pyinjective.proto.exchange import injective_chart_rpc_pb2 as exchange_dot_injective__chart__rpc__pb2


class InjectiveChartRPCStub(object):
    """InjectiveChartRPC implements historical chart data retrieval.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SpotMarketHistory = channel.unary_unary(
                '/injective_chart_rpc.InjectiveChartRPC/SpotMarketHistory',
                request_serializer=exchange_dot_injective__chart__rpc__pb2.SpotMarketHistoryRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__chart__rpc__pb2.SpotMarketHistoryResponse.FromString,
                _registered_method=True)
        self.DerivativeMarketHistory = channel.unary_unary(
                '/injective_chart_rpc.InjectiveChartRPC/DerivativeMarketHistory',
                request_serializer=exchange_dot_injective__chart__rpc__pb2.DerivativeMarketHistoryRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__chart__rpc__pb2.DerivativeMarketHistoryResponse.FromString,
                _registered_method=True)
        self.SpotMarketSummary = channel.unary_unary(
                '/injective_chart_rpc.InjectiveChartRPC/SpotMarketSummary',
                request_serializer=exchange_dot_injective__chart__rpc__pb2.SpotMarketSummaryRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__chart__rpc__pb2.SpotMarketSummaryResponse.FromString,
                _registered_method=True)
        self.AllSpotMarketSummary = channel.unary_unary(
                '/injective_chart_rpc.InjectiveChartRPC/AllSpotMarketSummary',
                request_serializer=exchange_dot_injective__chart__rpc__pb2.AllSpotMarketSummaryRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__chart__rpc__pb2.AllSpotMarketSummaryResponse.FromString,
                _registered_method=True)
        self.DerivativeMarketSummary = channel.unary_unary(
                '/injective_chart_rpc.InjectiveChartRPC/DerivativeMarketSummary',
                request_serializer=exchange_dot_injective__chart__rpc__pb2.DerivativeMarketSummaryRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__chart__rpc__pb2.DerivativeMarketSummaryResponse.FromString,
                _registered_method=True)
        self.AllDerivativeMarketSummary = channel.unary_unary(
                '/injective_chart_rpc.InjectiveChartRPC/AllDerivativeMarketSummary',
                request_serializer=exchange_dot_injective__chart__rpc__pb2.AllDerivativeMarketSummaryRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__chart__rpc__pb2.AllDerivativeMarketSummaryResponse.FromString,
                _registered_method=True)
        self.MarketSnapshot = channel.unary_unary(
                '/injective_chart_rpc.InjectiveChartRPC/MarketSnapshot',
                request_serializer=exchange_dot_injective__chart__rpc__pb2.MarketSnapshotRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__chart__rpc__pb2.MarketSnapshotResponse.FromString,
                _registered_method=True)


class InjectiveChartRPCServicer(object):
    """InjectiveChartRPC implements historical chart data retrieval.
    """

    def SpotMarketHistory(self, request, context):
        """Request for history bars of spotMarket for TradingView.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DerivativeMarketHistory(self, request, context):
        """Request for history bars of derivativeMarket for TradingView.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SpotMarketSummary(self, request, context):
        """Gets spot market summary for the latest interval (hour, day, month)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AllSpotMarketSummary(self, request, context):
        """Gets batch summary for all active markets, for the latest interval (hour,
        day, month)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DerivativeMarketSummary(self, request, context):
        """Gets derivative market summary for the latest interval (hour, day, month)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AllDerivativeMarketSummary(self, request, context):
        """Gets batch summary for all active markets, for the latest interval (hour,
        day, month)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MarketSnapshot(self, request, context):
        """Request for cached markets history bars. Max age is 1h.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_InjectiveChartRPCServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SpotMarketHistory': grpc.unary_unary_rpc_method_handler(
                    servicer.SpotMarketHistory,
                    request_deserializer=exchange_dot_injective__chart__rpc__pb2.SpotMarketHistoryRequest.FromString,
                    response_serializer=exchange_dot_injective__chart__rpc__pb2.SpotMarketHistoryResponse.SerializeToString,
            ),
            'DerivativeMarketHistory': grpc.unary_unary_rpc_method_handler(
                    servicer.DerivativeMarketHistory,
                    request_deserializer=exchange_dot_injective__chart__rpc__pb2.DerivativeMarketHistoryRequest.FromString,
                    response_serializer=exchange_dot_injective__chart__rpc__pb2.DerivativeMarketHistoryResponse.SerializeToString,
            ),
            'SpotMarketSummary': grpc.unary_unary_rpc_method_handler(
                    servicer.SpotMarketSummary,
                    request_deserializer=exchange_dot_injective__chart__rpc__pb2.SpotMarketSummaryRequest.FromString,
                    response_serializer=exchange_dot_injective__chart__rpc__pb2.SpotMarketSummaryResponse.SerializeToString,
            ),
            'AllSpotMarketSummary': grpc.unary_unary_rpc_method_handler(
                    servicer.AllSpotMarketSummary,
                    request_deserializer=exchange_dot_injective__chart__rpc__pb2.AllSpotMarketSummaryRequest.FromString,
                    response_serializer=exchange_dot_injective__chart__rpc__pb2.AllSpotMarketSummaryResponse.SerializeToString,
            ),
            'DerivativeMarketSummary': grpc.unary_unary_rpc_method_handler(
                    servicer.DerivativeMarketSummary,
                    request_deserializer=exchange_dot_injective__chart__rpc__pb2.DerivativeMarketSummaryRequest.FromString,
                    response_serializer=exchange_dot_injective__chart__rpc__pb2.DerivativeMarketSummaryResponse.SerializeToString,
            ),
            'AllDerivativeMarketSummary': grpc.unary_unary_rpc_method_handler(
                    servicer.AllDerivativeMarketSummary,
                    request_deserializer=exchange_dot_injective__chart__rpc__pb2.AllDerivativeMarketSummaryRequest.FromString,
                    response_serializer=exchange_dot_injective__chart__rpc__pb2.AllDerivativeMarketSummaryResponse.SerializeToString,
            ),
            'MarketSnapshot': grpc.unary_unary_rpc_method_handler(
                    servicer.MarketSnapshot,
                    request_deserializer=exchange_dot_injective__chart__rpc__pb2.MarketSnapshotRequest.FromString,
                    response_serializer=exchange_dot_injective__chart__rpc__pb2.MarketSnapshotResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'injective_chart_rpc.InjectiveChartRPC', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('injective_chart_rpc.InjectiveChartRPC', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class InjectiveChartRPC(object):
    """InjectiveChartRPC implements historical chart data retrieval.
    """

    @staticmethod
    def SpotMarketHistory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective_chart_rpc.InjectiveChartRPC/SpotMarketHistory',
            exchange_dot_injective__chart__rpc__pb2.SpotMarketHistoryRequest.SerializeToString,
            exchange_dot_injective__chart__rpc__pb2.SpotMarketHistoryResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DerivativeMarketHistory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective_chart_rpc.InjectiveChartRPC/DerivativeMarketHistory',
            exchange_dot_injective__chart__rpc__pb2.DerivativeMarketHistoryRequest.SerializeToString,
            exchange_dot_injective__chart__rpc__pb2.DerivativeMarketHistoryResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SpotMarketSummary(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective_chart_rpc.InjectiveChartRPC/SpotMarketSummary',
            exchange_dot_injective__chart__rpc__pb2.SpotMarketSummaryRequest.SerializeToString,
            exchange_dot_injective__chart__rpc__pb2.SpotMarketSummaryResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AllSpotMarketSummary(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective_chart_rpc.InjectiveChartRPC/AllSpotMarketSummary',
            exchange_dot_injective__chart__rpc__pb2.AllSpotMarketSummaryRequest.SerializeToString,
            exchange_dot_injective__chart__rpc__pb2.AllSpotMarketSummaryResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DerivativeMarketSummary(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective_chart_rpc.InjectiveChartRPC/DerivativeMarketSummary',
            exchange_dot_injective__chart__rpc__pb2.DerivativeMarketSummaryRequest.SerializeToString,
            exchange_dot_injective__chart__rpc__pb2.DerivativeMarketSummaryResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AllDerivativeMarketSummary(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective_chart_rpc.InjectiveChartRPC/AllDerivativeMarketSummary',
            exchange_dot_injective__chart__rpc__pb2.AllDerivativeMarketSummaryRequest.SerializeToString,
            exchange_dot_injective__chart__rpc__pb2.AllDerivativeMarketSummaryResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def MarketSnapshot(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective_chart_rpc.InjectiveChartRPC/MarketSnapshot',
            exchange_dot_injective__chart__rpc__pb2.MarketSnapshotRequest.SerializeToString,
            exchange_dot_injective__chart__rpc__pb2.MarketSnapshotResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/bank/v1beta1/genesis.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from pyinjective.proto.cosmos.bank.v1beta1 import bank_pb2 as cosmos_dot_bank_dot_v1beta1_dot_bank__pb2
from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!cosmos/bank/v1beta1/genesis.proto\x12\x13\x63osmos.bank.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x1e\x63osmos/bank/v1beta1/bank.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x11\x61mino/amino.proto\"\xaf\x03\n\x0cGenesisState\x12>\n\x06params\x18\x01 \x01(\x0b\x32\x1b.cosmos.bank.v1beta1.ParamsB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x06params\x12\x43\n\x08\x62\x61lances\x18\x02 \x03(\x0b\x32\x1c.cosmos.bank.v1beta1.BalanceB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x08\x62\x61lances\x12y\n\x06supply\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBF\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x9a\xe7\xb0*\x0clegacy_coins\xa8\xe7\xb0*\x01R\x06supply\x12O\n\x0e\x64\x65nom_metadata\x18\x04 \x03(\x0b\x32\x1d.cosmos.bank.v1beta1.MetadataB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\rdenomMetadata\x12N\n\x0csend_enabled\x18\x05 \x03(\x0b\x32 .cosmos.bank.v1beta1.SendEnabledB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x0bsendEnabled\"\xc0\x01\n\x07\x42\x61lance\x12\x32\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x07\x61\x64\x64ress\x12w\n\x05\x63oins\x18\x02 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBF\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x9a\xe7\xb0*\x0clegacy_coins\xa8\xe7\xb0*\x01R\x05\x63oins:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x42\xc0\x01\n\x17\x63om.cosmos.bank.v1beta1B\x0cGenesisProtoP\x01Z)github.com/cosmos/cosmos-sdk/x/bank/types\xa2\x02\x03\x43\x42X\xaa\x02\x13\x43osmos.Bank.V1beta1\xca\x02\x13\x43osmos\\Bank\\V1beta1\xe2\x02\x1f\x43osmos\\Bank\\V1beta1\\GPBMetadata\xea\x02\x15\x43osmos::Bank::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.bank.v1beta1.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027com.cosmos.bank.v1beta1B\014GenesisProtoP\001Z)github.com/cosmos/cosmos-sdk/x/bank/types\242\002\003CBX\252\002\023Cosmos.Bank.V1beta1\312\002\023Cosmos\\Bank\\V1beta1\342\002\037Cosmos\\Bank\\V1beta1\\GPBMetadata\352\002\025Cosmos::Bank::V1beta1'
  _globals['_GENESISSTATE'].fields_by_name['params']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['params']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_GENESISSTATE'].fields_by_name['balances']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['balances']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_GENESISSTATE'].fields_by_name['supply']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['supply']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\232\347\260*\014legacy_coins\250\347\260*\001'
  _globals['_GENESISSTATE'].fields_by_name['denom_metadata']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['denom_metadata']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_GENESISSTATE'].fields_by_name['send_enabled']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['send_enabled']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_BALANCE'].fields_by_name['address']._loaded_options = None
  _globals['_BALANCE'].fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_BALANCE'].fields_by_name['coins']._loaded_options = None
  _globals['_BALANCE'].fields_by_name['coins']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\232\347\260*\014legacy_coins\250\347\260*\001'
  _globals['_BALANCE']._loaded_options = None
  _globals['_BALANCE']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_GENESISSTATE']._serialized_start=191
  _globals['_GENESISSTATE']._serialized_end=622
  _globals['_BALANCE']._serialized_start=625
  _globals['_BALANCE']._serialized_end=817
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/applications/interchain_accounts/host/v1/tx.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from pyinjective.proto.ibc.applications.interchain_accounts.host.v1 import host_pb2 as ibc_dot_applications_dot_interchain__accounts_dot_host_dot_v1_dot_host__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5ibc/applications/interchain_accounts/host/v1/tx.proto\x12,ibc.applications.interchain_accounts.host.v1\x1a\x14gogoproto/gogo.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x37ibc/applications/interchain_accounts/host/v1/host.proto\"\x8e\x01\n\x0fMsgUpdateParams\x12\x16\n\x06signer\x18\x01 \x01(\tR\x06signer\x12R\n\x06params\x18\x02 \x01(\x0b\x32\x34.ibc.applications.interchain_accounts.host.v1.ParamsB\x04\xc8\xde\x1f\x00R\x06params:\x0f\x88\xa0\x1f\x00\x82\xe7\xb0*\x06signer\"\x19\n\x17MsgUpdateParamsResponse\"\x95\x01\n\x12MsgModuleQuerySafe\x12\x16\n\x06signer\x18\x01 \x01(\tR\x06signer\x12V\n\x08requests\x18\x02 \x03(\x0b\x32:.ibc.applications.interchain_accounts.host.v1.QueryRequestR\x08requests:\x0f\x88\xa0\x1f\x00\x82\xe7\xb0*\x06signer\"R\n\x1aMsgModuleQuerySafeResponse\x12\x16\n\x06height\x18\x01 \x01(\x04R\x06height\x12\x1c\n\tresponses\x18\x02 \x03(\x0cR\tresponses2\xc3\x02\n\x03Msg\x12\x94\x01\n\x0cUpdateParams\x12=.ibc.applications.interchain_accounts.host.v1.MsgUpdateParams\x1a\x45.ibc.applications.interchain_accounts.host.v1.MsgUpdateParamsResponse\x12\x9d\x01\n\x0fModuleQuerySafe\x12@.ibc.applications.interchain_accounts.host.v1.MsgModuleQuerySafe\x1aH.ibc.applications.interchain_accounts.host.v1.MsgModuleQuerySafeResponse\x1a\x05\x80\xe7\xb0*\x01\x42\xd8\x02\n0com.ibc.applications.interchain_accounts.host.v1B\x07TxProtoP\x01ZJgithub.com/cosmos/ibc-go/v8/modules/apps/27-interchain-accounts/host/types\xa2\x02\x04IAIH\xaa\x02+Ibc.Applications.InterchainAccounts.Host.V1\xca\x02+Ibc\\Applications\\InterchainAccounts\\Host\\V1\xe2\x02\x37Ibc\\Applications\\InterchainAccounts\\Host\\V1\\GPBMetadata\xea\x02/Ibc::Applications::InterchainAccounts::Host::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.applications.interchain_accounts.host.v1.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n0com.ibc.applications.interchain_accounts.host.v1B\007TxProtoP\001ZJgithub.com/cosmos/ibc-go/v8/modules/apps/27-interchain-accounts/host/types\242\002\004IAIH\252\002+Ibc.Applications.InterchainAccounts.Host.V1\312\002+Ibc\\Applications\\InterchainAccounts\\Host\\V1\342\0027Ibc\\Applications\\InterchainAccounts\\Host\\V1\\GPBMetadata\352\002/Ibc::Applications::InterchainAccounts::Host::V1'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_MSGUPDATEPARAMS']._loaded_options = None
  _globals['_MSGUPDATEPARAMS']._serialized_options = b'\210\240\037\000\202\347\260*\006signer'
  _globals['_MSGMODULEQUERYSAFE']._loaded_options = None
  _globals['_MSGMODULEQUERYSAFE']._serialized_options = b'\210\240\037\000\202\347\260*\006signer'
  _globals['_MSG']._loaded_options = None
  _globals['_MSG']._serialized_options = b'\200\347\260*\001'
  _globals['_MSGUPDATEPARAMS']._serialized_start=208
  _globals['_MSGUPDATEPARAMS']._serialized_end=350
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_start=352
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_end=377
  _globals['_MSGMODULEQUERYSAFE']._serialized_start=380
  _globals['_MSGMODULEQUERYSAFE']._serialized_end=529
  _globals['_MSGMODULEQUERYSAFERESPONSE']._serialized_start=531
  _globals['_MSGMODULEQUERYSAFERESPONSE']._serialized_end=613
  _globals['_MSG']._serialized_start=616
  _globals['_MSG']._serialized_end=939
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/types/v1beta1/tx_response.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)injective/types/v1beta1/tx_response.proto\x12\x17injective.types.v1beta1\"F\n\x18TxResponseGenericMessage\x12\x16\n\x06header\x18\x01 \x01(\tR\x06header\x12\x12\n\x04\x64\x61ta\x18\x02 \x01(\x0cR\x04\x64\x61ta\"_\n\x0eTxResponseData\x12M\n\x08messages\x18\x01 \x03(\x0b\x32\x31.injective.types.v1beta1.TxResponseGenericMessageR\x08messagesB\xeb\x01\n\x1b\x63om.injective.types.v1beta1B\x0fTxResponseProtoP\x01Z=github.com/InjectiveLabs/injective-core/injective-chain/types\xa2\x02\x03ITX\xaa\x02\x17Injective.Types.V1beta1\xca\x02\x17Injective\\Types\\V1beta1\xe2\x02#Injective\\Types\\V1beta1\\GPBMetadata\xea\x02\x19Injective::Types::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.types.v1beta1.tx_response_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033com.injective.types.v1beta1B\017TxResponseProtoP\001Z=github.com/InjectiveLabs/injective-core/injective-chain/types\242\002\003ITX\252\002\027Injective.Types.V1beta1\312\002\027Injective\\Types\\V1beta1\342\002#Injective\\Types\\V1beta1\\GPBMetadata\352\002\031Injective::Types::V1beta1'
  _globals['_TXRESPONSEGENERICMESSAGE']._serialized_start=70
  _globals['_TXRESPONSEGENERICMESSAGE']._serialized_end=140
  _globals['_TXRESPONSEDATA']._serialized_start=142
  _globals['_TXRESPONSEDATA']._serialized_end=237
# @@protoc_insertion_point(module_scope)



from decimal import Decimal

import requests
from eip712.messages import EIP712Message, EIP712Type
from eth_account.messages import _hash_eip191_message as hash_eip191_message
from hexbytes import HexBytes

from pyinjective.core.token import Token


class OrderInfo(EIP712Type):
    SubaccountId: "string"  # noqa: F821
    FeeRecipient: "string"  # noqa: F821
    Price: "string"  # noqa: F821
    Quantity: "string"  # noqa: F821


class SpotOrder(EIP712Message):
    _name_ = "Injective Protocol"
    _version_ = "2.0.0"
    _chainId_ = 888
    _verifyingContract_ = "0xCcCCccccCCCCcCCCCCCcCcCccCcCCCcCcccccccC"
    _salt_ = HexBytes("0x0000000000000000000000000000000000000000000000000000000000000000")

    MarketId: "string"  # noqa: F821
    OrderInfo: OrderInfo
    Salt: "string"  # noqa: F821
    OrderType: "string"  # noqa: F821
    TriggerPrice: "string"  # noqa: F821


class DerivativeOrder(EIP712Message):
    _name_ = "Injective Protocol"
    _version_ = "2.0.0"
    _chainId_ = 888
    _verifyingContract_ = "0xCcCCccccCCCCcCCCCCCcCcCccCcCCCcCcccccccC"
    _salt_ = HexBytes("0x0000000000000000000000000000000000000000000000000000000000000000")

    MarketId: "string"  # noqa: F821
    OrderInfo: OrderInfo
    OrderType: "string"  # noqa: F821
    Margin: "string"  # noqa: F821
    TriggerPrice: "string"  # noqa: F821
    Salt: "string"  # noqa: F821


# domain_separator = EIP712_domain.hash_struct()
order_type_dict = {0: "\x00", 1: "\x01", 2: "\x02", 3: "\x03", 4: "\x04", 5: "\x05", 6: "\x06", 7: "\x07", 8: "\x08"}


class OrderHashResponse:
    def __init__(
        self,
        spot: [str] = None,
        derivative: [str] = None,
    ):
        self.spot = spot
        self.derivative = derivative


class OrderHashManager:
    def __init__(
        self,
        address,
        network,
        subaccount_indexes: [int] = None,
    ):
        self.address = address
        self.subacc_nonces = dict()

        for i in subaccount_indexes:
            subaccount_id = address.get_subaccount_id(index=i)
            url = network.lcd_endpoint + "/injective/exchange/v1beta1/exchange/" + subaccount_id
            res = requests.get(url=url)
            nonce = res.json()["nonce"]
            self.subacc_nonces[i] = [subaccount_id, nonce + 1]

    def compute_order_hashes(self, spot_orders, derivative_orders, subaccount_index) -> [str]:
        if len(spot_orders) + len(derivative_orders) == 0:
            return []

        order_hashes = OrderHashResponse(spot=[], derivative=[])

        for o in spot_orders:
            msg = build_eip712_msg(o, self.subacc_nonces[subaccount_index][1])
            order_hash = hash_order(msg)
            order_hashes.spot.append(order_hash)
            self.subacc_nonces[subaccount_index][1] += 1

        for o in derivative_orders:
            msg = build_eip712_msg(o, self.subacc_nonces[subaccount_index][1])
            order_hash = hash_order(msg)
            order_hashes.derivative.append(order_hash)
            self.subacc_nonces[subaccount_index][1] += 1

        return order_hashes


def param_to_backend_go(param: str) -> str:
    go_param = Token.convert_value_from_extended_decimal_format(value=Decimal(param))
    return f"{go_param.normalize():.18f}"


def parse_order_type(order):
    return order_type_dict[order.order_type]


def build_eip712_msg(order, nonce):
    if order.__class__.__name__ == "SpotOrder":
        go_price = param_to_backend_go(order.order_info.price)
        go_trigger_price = param_to_backend_go(order.trigger_price)
        go_quantity = param_to_backend_go(order.order_info.quantity)
        go_order_type = parse_order_type(order)
        return SpotOrder(
            MarketId=order.market_id,
            OrderInfo=OrderInfo(
                SubaccountId=order.order_info.subaccount_id,
                FeeRecipient=order.order_info.fee_recipient,
                Price=go_price,
                Quantity=go_quantity,
            ),
            Salt=str(nonce),
            OrderType=go_order_type,
            TriggerPrice=go_trigger_price,
        )
    if order.__class__.__name__ == "DerivativeOrder":
        go_price = param_to_backend_go(order.order_info.price)
        go_trigger_price = param_to_backend_go(order.trigger_price)
        go_quantity = param_to_backend_go(order.order_info.quantity)
        go_margin = param_to_backend_go(order.margin)
        go_order_type = parse_order_type(order)
        return DerivativeOrder(
            MarketId=order.market_id,
            OrderInfo=OrderInfo(
                SubaccountId=order.order_info.subaccount_id,
                FeeRecipient=order.order_info.fee_recipient,
                Price=go_price,
                Quantity=go_quantity,
            ),
            Salt=str(nonce),
            OrderType=go_order_type,
            TriggerPrice=go_trigger_price,
            Margin=go_margin,
        )


def hash_order(msg):
    signable_message = msg.signable_message
    hex_digest = hash_eip191_message(signable_message=signable_message).hex()
    return "0x" + hex_digest



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/core/client/v1/genesis.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.ibc.core.client.v1 import client_pb2 as ibc_dot_core_dot_client_dot_v1_dot_client__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n ibc/core/client/v1/genesis.proto\x12\x12ibc.core.client.v1\x1a\x1fibc/core/client/v1/client.proto\x1a\x14gogoproto/gogo.proto\"\xe6\x03\n\x0cGenesisState\x12\x63\n\x07\x63lients\x18\x01 \x03(\x0b\x32).ibc.core.client.v1.IdentifiedClientStateB\x1e\xc8\xde\x1f\x00\xaa\xdf\x1f\x16IdentifiedClientStatesR\x07\x63lients\x12v\n\x11\x63lients_consensus\x18\x02 \x03(\x0b\x32).ibc.core.client.v1.ClientConsensusStatesB\x1e\xc8\xde\x1f\x00\xaa\xdf\x1f\x16\x43lientsConsensusStatesR\x10\x63lientsConsensus\x12^\n\x10\x63lients_metadata\x18\x03 \x03(\x0b\x32-.ibc.core.client.v1.IdentifiedGenesisMetadataB\x04\xc8\xde\x1f\x00R\x0f\x63lientsMetadata\x12\x38\n\x06params\x18\x04 \x01(\x0b\x32\x1a.ibc.core.client.v1.ParamsB\x04\xc8\xde\x1f\x00R\x06params\x12-\n\x10\x63reate_localhost\x18\x05 \x01(\x08\x42\x02\x18\x01R\x0f\x63reateLocalhost\x12\x30\n\x14next_client_sequence\x18\x06 \x01(\x04R\x12nextClientSequence\"?\n\x0fGenesisMetadata\x12\x10\n\x03key\x18\x01 \x01(\x0cR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x0cR\x05value:\x04\x88\xa0\x1f\x00\"\x8c\x01\n\x19IdentifiedGenesisMetadata\x12\x1b\n\tclient_id\x18\x01 \x01(\tR\x08\x63lientId\x12R\n\x0f\x63lient_metadata\x18\x02 \x03(\x0b\x32#.ibc.core.client.v1.GenesisMetadataB\x04\xc8\xde\x1f\x00R\x0e\x63lientMetadataB\xcb\x01\n\x16\x63om.ibc.core.client.v1B\x0cGenesisProtoP\x01Z8github.com/cosmos/ibc-go/v8/modules/core/02-client/types\xa2\x02\x03ICC\xaa\x02\x12Ibc.Core.Client.V1\xca\x02\x12Ibc\\Core\\Client\\V1\xe2\x02\x1eIbc\\Core\\Client\\V1\\GPBMetadata\xea\x02\x15Ibc::Core::Client::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.core.client.v1.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.ibc.core.client.v1B\014GenesisProtoP\001Z8github.com/cosmos/ibc-go/v8/modules/core/02-client/types\242\002\003ICC\252\002\022Ibc.Core.Client.V1\312\002\022Ibc\\Core\\Client\\V1\342\002\036Ibc\\Core\\Client\\V1\\GPBMetadata\352\002\025Ibc::Core::Client::V1'
  _globals['_GENESISSTATE'].fields_by_name['clients']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['clients']._serialized_options = b'\310\336\037\000\252\337\037\026IdentifiedClientStates'
  _globals['_GENESISSTATE'].fields_by_name['clients_consensus']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['clients_consensus']._serialized_options = b'\310\336\037\000\252\337\037\026ClientsConsensusStates'
  _globals['_GENESISSTATE'].fields_by_name['clients_metadata']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['clients_metadata']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['params']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['create_localhost']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['create_localhost']._serialized_options = b'\030\001'
  _globals['_GENESISMETADATA']._loaded_options = None
  _globals['_GENESISMETADATA']._serialized_options = b'\210\240\037\000'
  _globals['_IDENTIFIEDGENESISMETADATA'].fields_by_name['client_metadata']._loaded_options = None
  _globals['_IDENTIFIEDGENESISMETADATA'].fields_by_name['client_metadata']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE']._serialized_start=112
  _globals['_GENESISSTATE']._serialized_end=598
  _globals['_GENESISMETADATA']._serialized_start=600
  _globals['_GENESISMETADATA']._serialized_end=663
  _globals['_IDENTIFIEDGENESISMETADATA']._serialized_start=666
  _globals['_IDENTIFIEDGENESISMETADATA']._serialized_end=806
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/core/channel/v1/upgrade.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.ibc.core.channel.v1 import channel_pb2 as ibc_dot_core_dot_channel_dot_v1_dot_channel__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!ibc/core/channel/v1/upgrade.proto\x12\x13ibc.core.channel.v1\x1a\x14gogoproto/gogo.proto\x1a!ibc/core/channel/v1/channel.proto\"\xbd\x01\n\x07Upgrade\x12@\n\x06\x66ields\x18\x01 \x01(\x0b\x32\".ibc.core.channel.v1.UpgradeFieldsB\x04\xc8\xde\x1f\x00R\x06\x66ields\x12<\n\x07timeout\x18\x02 \x01(\x0b\x32\x1c.ibc.core.channel.v1.TimeoutB\x04\xc8\xde\x1f\x00R\x07timeout\x12,\n\x12next_sequence_send\x18\x03 \x01(\x04R\x10nextSequenceSend:\x04\x88\xa0\x1f\x00\"\x90\x01\n\rUpgradeFields\x12\x36\n\x08ordering\x18\x01 \x01(\x0e\x32\x1a.ibc.core.channel.v1.OrderR\x08ordering\x12\'\n\x0f\x63onnection_hops\x18\x02 \x03(\tR\x0e\x63onnectionHops\x12\x18\n\x07version\x18\x03 \x01(\tR\x07version:\x04\x88\xa0\x1f\x00\"J\n\x0c\x45rrorReceipt\x12\x1a\n\x08sequence\x18\x01 \x01(\x04R\x08sequence\x12\x18\n\x07message\x18\x02 \x01(\tR\x07message:\x04\x88\xa0\x1f\x00\x42\xd1\x01\n\x17\x63om.ibc.core.channel.v1B\x0cUpgradeProtoP\x01Z9github.com/cosmos/ibc-go/v8/modules/core/04-channel/types\xa2\x02\x03ICC\xaa\x02\x13Ibc.Core.Channel.V1\xca\x02\x13Ibc\\Core\\Channel\\V1\xe2\x02\x1fIbc\\Core\\Channel\\V1\\GPBMetadata\xea\x02\x16Ibc::Core::Channel::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.core.channel.v1.upgrade_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027com.ibc.core.channel.v1B\014UpgradeProtoP\001Z9github.com/cosmos/ibc-go/v8/modules/core/04-channel/types\242\002\003ICC\252\002\023Ibc.Core.Channel.V1\312\002\023Ibc\\Core\\Channel\\V1\342\002\037Ibc\\Core\\Channel\\V1\\GPBMetadata\352\002\026Ibc::Core::Channel::V1'
  _globals['_UPGRADE'].fields_by_name['fields']._loaded_options = None
  _globals['_UPGRADE'].fields_by_name['fields']._serialized_options = b'\310\336\037\000'
  _globals['_UPGRADE'].fields_by_name['timeout']._loaded_options = None
  _globals['_UPGRADE'].fields_by_name['timeout']._serialized_options = b'\310\336\037\000'
  _globals['_UPGRADE']._loaded_options = None
  _globals['_UPGRADE']._serialized_options = b'\210\240\037\000'
  _globals['_UPGRADEFIELDS']._loaded_options = None
  _globals['_UPGRADEFIELDS']._serialized_options = b'\210\240\037\000'
  _globals['_ERRORRECEIPT']._loaded_options = None
  _globals['_ERRORRECEIPT']._serialized_options = b'\210\240\037\000'
  _globals['_UPGRADE']._serialized_start=116
  _globals['_UPGRADE']._serialized_end=305
  _globals['_UPGRADEFIELDS']._serialized_start=308
  _globals['_UPGRADEFIELDS']._serialized_end=452
  _globals['_ERRORRECEIPT']._serialized_start=454
  _globals['_ERRORRECEIPT']._serialized_end=528
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/params/v1beta1/params.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"cosmos/params/v1beta1/params.proto\x12\x15\x63osmos.params.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x11\x61mino/amino.proto\"\xe5\x01\n\x17ParameterChangeProposal\x12\x14\n\x05title\x18\x01 \x01(\tR\x05title\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12G\n\x07\x63hanges\x18\x03 \x03(\x0b\x32\".cosmos.params.v1beta1.ParamChangeB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x07\x63hanges:I\x88\xa0\x1f\x00\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\x8a\xe7\xb0*\"cosmos-sdk/ParameterChangeProposal\"Q\n\x0bParamChange\x12\x1a\n\x08subspace\x18\x01 \x01(\tR\x08subspace\x12\x10\n\x03key\x18\x02 \x01(\tR\x03key\x12\x14\n\x05value\x18\x03 \x01(\tR\x05valueB\xd8\x01\n\x19\x63om.cosmos.params.v1beta1B\x0bParamsProtoP\x01Z4github.com/cosmos/cosmos-sdk/x/params/types/proposal\xa2\x02\x03\x43PX\xaa\x02\x15\x43osmos.Params.V1beta1\xca\x02\x15\x43osmos\\Params\\V1beta1\xe2\x02!Cosmos\\Params\\V1beta1\\GPBMetadata\xea\x02\x17\x43osmos::Params::V1beta1\xa8\xe2\x1e\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.params.v1beta1.params_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031com.cosmos.params.v1beta1B\013ParamsProtoP\001Z4github.com/cosmos/cosmos-sdk/x/params/types/proposal\242\002\003CPX\252\002\025Cosmos.Params.V1beta1\312\002\025Cosmos\\Params\\V1beta1\342\002!Cosmos\\Params\\V1beta1\\GPBMetadata\352\002\027Cosmos::Params::V1beta1\250\342\036\001'
  _globals['_PARAMETERCHANGEPROPOSAL'].fields_by_name['changes']._loaded_options = None
  _globals['_PARAMETERCHANGEPROPOSAL'].fields_by_name['changes']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_PARAMETERCHANGEPROPOSAL']._loaded_options = None
  _globals['_PARAMETERCHANGEPROPOSAL']._serialized_options = b'\210\240\037\000\312\264-\032cosmos.gov.v1beta1.Content\212\347\260*\"cosmos-sdk/ParameterChangeProposal'
  _globals['_PARAMETERCHANGEPROPOSAL']._serialized_start=130
  _globals['_PARAMETERCHANGEPROPOSAL']._serialized_end=359
  _globals['_PARAMCHANGE']._serialized_start=361
  _globals['_PARAMCHANGE']._serialized_end=442
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/permissions/v1beta1/genesis.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.injective.permissions.v1beta1 import params_pb2 as injective_dot_permissions_dot_v1beta1_dot_params__pb2
from pyinjective.proto.injective.permissions.v1beta1 import permissions_pb2 as injective_dot_permissions_dot_v1beta1_dot_permissions__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+injective/permissions/v1beta1/genesis.proto\x12\x1dinjective.permissions.v1beta1\x1a\x14gogoproto/gogo.proto\x1a*injective/permissions/v1beta1/params.proto\x1a/injective/permissions/v1beta1/permissions.proto\"\xee\x01\n\x0cGenesisState\x12\x43\n\x06params\x18\x01 \x01(\x0b\x32%.injective.permissions.v1beta1.ParamsB\x04\xc8\xde\x1f\x00R\x06params\x12N\n\nnamespaces\x18\x02 \x03(\x0b\x32(.injective.permissions.v1beta1.NamespaceB\x04\xc8\xde\x1f\x00R\nnamespaces\x12I\n\x08vouchers\x18\x03 \x03(\x0b\x32-.injective.permissions.v1beta1.AddressVoucherR\x08vouchersB\x9a\x02\n!com.injective.permissions.v1beta1B\x0cGenesisProtoP\x01ZQgithub.com/InjectiveLabs/injective-core/injective-chain/modules/permissions/types\xa2\x02\x03IPX\xaa\x02\x1dInjective.Permissions.V1beta1\xca\x02\x1dInjective\\Permissions\\V1beta1\xe2\x02)Injective\\Permissions\\V1beta1\\GPBMetadata\xea\x02\x1fInjective::Permissions::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.permissions.v1beta1.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!com.injective.permissions.v1beta1B\014GenesisProtoP\001ZQgithub.com/InjectiveLabs/injective-core/injective-chain/modules/permissions/types\242\002\003IPX\252\002\035Injective.Permissions.V1beta1\312\002\035Injective\\Permissions\\V1beta1\342\002)Injective\\Permissions\\V1beta1\\GPBMetadata\352\002\037Injective::Permissions::V1beta1'
  _globals['_GENESISSTATE'].fields_by_name['params']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['namespaces']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['namespaces']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE']._serialized_start=194
  _globals['_GENESISSTATE']._serialized_end=432
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/auth/v1beta1/genesis.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.cosmos.auth.v1beta1 import auth_pb2 as cosmos_dot_auth_dot_v1beta1_dot_auth__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!cosmos/auth/v1beta1/genesis.proto\x12\x13\x63osmos.auth.v1beta1\x1a\x19google/protobuf/any.proto\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/auth/v1beta1/auth.proto\x1a\x11\x61mino/amino.proto\"\x80\x01\n\x0cGenesisState\x12>\n\x06params\x18\x01 \x01(\x0b\x32\x1b.cosmos.auth.v1beta1.ParamsB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x06params\x12\x30\n\x08\x61\x63\x63ounts\x18\x02 \x03(\x0b\x32\x14.google.protobuf.AnyR\x08\x61\x63\x63ountsB\xc0\x01\n\x17\x63om.cosmos.auth.v1beta1B\x0cGenesisProtoP\x01Z)github.com/cosmos/cosmos-sdk/x/auth/types\xa2\x02\x03\x43\x41X\xaa\x02\x13\x43osmos.Auth.V1beta1\xca\x02\x13\x43osmos\\Auth\\V1beta1\xe2\x02\x1f\x43osmos\\Auth\\V1beta1\\GPBMetadata\xea\x02\x15\x43osmos::Auth::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.auth.v1beta1.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027com.cosmos.auth.v1beta1B\014GenesisProtoP\001Z)github.com/cosmos/cosmos-sdk/x/auth/types\242\002\003CAX\252\002\023Cosmos.Auth.V1beta1\312\002\023Cosmos\\Auth\\V1beta1\342\002\037Cosmos\\Auth\\V1beta1\\GPBMetadata\352\002\025Cosmos::Auth::V1beta1'
  _globals['_GENESISSTATE'].fields_by_name['params']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['params']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_GENESISSTATE']._serialized_start=159
  _globals['_GENESISSTATE']._serialized_end=287
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/store/streaming/abci/grpc.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cometbft.abci.v1 import types_pb2 as cometbft_dot_abci_dot_v1_dot_types__pb2
from pyinjective.proto.cosmos.store.v1beta1 import listening_pb2 as cosmos_dot_store_dot_v1beta1_dot_listening__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&cosmos/store/streaming/abci/grpc.proto\x12\x1b\x63osmos.store.streaming.abci\x1a\x1c\x63ometbft/abci/v1/types.proto\x1a$cosmos/store/v1beta1/listening.proto\"\x91\x01\n\x1aListenFinalizeBlockRequest\x12\x38\n\x03req\x18\x01 \x01(\x0b\x32&.cometbft.abci.v1.FinalizeBlockRequestR\x03req\x12\x39\n\x03res\x18\x02 \x01(\x0b\x32\'.cometbft.abci.v1.FinalizeBlockResponseR\x03res\"\x1d\n\x1bListenFinalizeBlockResponse\"\xae\x01\n\x13ListenCommitRequest\x12!\n\x0c\x62lock_height\x18\x01 \x01(\x03R\x0b\x62lockHeight\x12\x32\n\x03res\x18\x02 \x01(\x0b\x32 .cometbft.abci.v1.CommitResponseR\x03res\x12@\n\nchange_set\x18\x03 \x03(\x0b\x32!.cosmos.store.v1beta1.StoreKVPairR\tchangeSet\"\x16\n\x14ListenCommitResponse2\x95\x02\n\x13\x41\x42\x43IListenerService\x12\x88\x01\n\x13ListenFinalizeBlock\x12\x37.cosmos.store.streaming.abci.ListenFinalizeBlockRequest\x1a\x38.cosmos.store.streaming.abci.ListenFinalizeBlockResponse\x12s\n\x0cListenCommit\x12\x30.cosmos.store.streaming.abci.ListenCommitRequest\x1a\x31.cosmos.store.streaming.abci.ListenCommitResponseB\xdf\x01\n\x1f\x63om.cosmos.store.streaming.abciB\tGrpcProtoP\x01Z!cosmossdk.io/store/streaming/abci\xa2\x02\x04\x43SSA\xaa\x02\x1b\x43osmos.Store.Streaming.Abci\xca\x02\x1b\x43osmos\\Store\\Streaming\\Abci\xe2\x02\'Cosmos\\Store\\Streaming\\Abci\\GPBMetadata\xea\x02\x1e\x43osmos::Store::Streaming::Abcib\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.store.streaming.abci.grpc_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\037com.cosmos.store.streaming.abciB\tGrpcProtoP\001Z!cosmossdk.io/store/streaming/abci\242\002\004CSSA\252\002\033Cosmos.Store.Streaming.Abci\312\002\033Cosmos\\Store\\Streaming\\Abci\342\002\'Cosmos\\Store\\Streaming\\Abci\\GPBMetadata\352\002\036Cosmos::Store::Streaming::Abci'
  _globals['_LISTENFINALIZEBLOCKREQUEST']._serialized_start=140
  _globals['_LISTENFINALIZEBLOCKREQUEST']._serialized_end=285
  _globals['_LISTENFINALIZEBLOCKRESPONSE']._serialized_start=287
  _globals['_LISTENFINALIZEBLOCKRESPONSE']._serialized_end=316
  _globals['_LISTENCOMMITREQUEST']._serialized_start=319
  _globals['_LISTENCOMMITREQUEST']._serialized_end=493
  _globals['_LISTENCOMMITRESPONSE']._serialized_start=495
  _globals['_LISTENCOMMITRESPONSE']._serialized_end=517
  _globals['_ABCILISTENERSERVICE']._serialized_start=520
  _globals['_ABCILISTENERSERVICE']._serialized_end=797
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/evm/v1/log.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ainjective/evm/v1/log.proto\x12\x10injective.evm.v1\x1a\x14gogoproto/gogo.proto\"\xca\x02\n\x03Log\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress\x12\x16\n\x06topics\x18\x02 \x03(\tR\x06topics\x12\x12\n\x04\x64\x61ta\x18\x03 \x01(\x0cR\x04\x64\x61ta\x12\x32\n\x0c\x62lock_number\x18\x04 \x01(\x04\x42\x0f\xea\xde\x1f\x0b\x62lockNumberR\x0b\x62lockNumber\x12,\n\x07tx_hash\x18\x05 \x01(\tB\x13\xea\xde\x1f\x0ftransactionHashR\x06txHash\x12/\n\x08tx_index\x18\x06 \x01(\x04\x42\x14\xea\xde\x1f\x10transactionIndexR\x07txIndex\x12,\n\nblock_hash\x18\x07 \x01(\tB\r\xea\xde\x1f\tblockHashR\tblockHash\x12\"\n\x05index\x18\x08 \x01(\x04\x42\x0c\xea\xde\x1f\x08logIndexR\x05index\x12\x18\n\x07removed\x18\t \x01(\x08R\x07removedB\xcd\x01\n\x14\x63om.injective.evm.v1B\x08LogProtoP\x01ZIgithub.com/InjectiveLabs/injective-core/injective-chain/modules/evm/types\xa2\x02\x03IEX\xaa\x02\x10Injective.Evm.V1\xca\x02\x10Injective\\Evm\\V1\xe2\x02\x1cInjective\\Evm\\V1\\GPBMetadata\xea\x02\x12Injective::Evm::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.evm.v1.log_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024com.injective.evm.v1B\010LogProtoP\001ZIgithub.com/InjectiveLabs/injective-core/injective-chain/modules/evm/types\242\002\003IEX\252\002\020Injective.Evm.V1\312\002\020Injective\\Evm\\V1\342\002\034Injective\\Evm\\V1\\GPBMetadata\352\002\022Injective::Evm::V1'
  _globals['_LOG'].fields_by_name['block_number']._loaded_options = None
  _globals['_LOG'].fields_by_name['block_number']._serialized_options = b'\352\336\037\013blockNumber'
  _globals['_LOG'].fields_by_name['tx_hash']._loaded_options = None
  _globals['_LOG'].fields_by_name['tx_hash']._serialized_options = b'\352\336\037\017transactionHash'
  _globals['_LOG'].fields_by_name['tx_index']._loaded_options = None
  _globals['_LOG'].fields_by_name['tx_index']._serialized_options = b'\352\336\037\020transactionIndex'
  _globals['_LOG'].fields_by_name['block_hash']._loaded_options = None
  _globals['_LOG'].fields_by_name['block_hash']._serialized_options = b'\352\336\037\tblockHash'
  _globals['_LOG'].fields_by_name['index']._loaded_options = None
  _globals['_LOG'].fields_by_name['index']._serialized_options = b'\352\336\037\010logIndex'
  _globals['_LOG']._serialized_start=71
  _globals['_LOG']._serialized_end=401
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/insurance/v1beta1/events.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from pyinjective.proto.injective.insurance.v1beta1 import insurance_pb2 as injective_dot_insurance_dot_v1beta1_dot_insurance__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(injective/insurance/v1beta1/events.proto\x12\x1binjective.insurance.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a+injective/insurance/v1beta1/insurance.proto\"Z\n\x18\x45ventInsuranceFundUpdate\x12>\n\x04\x66und\x18\x01 \x01(\x0b\x32*.injective.insurance.v1beta1.InsuranceFundR\x04\x66und\"e\n\x16\x45ventRequestRedemption\x12K\n\x08schedule\x18\x01 \x01(\x0b\x32/.injective.insurance.v1beta1.RedemptionScheduleR\x08schedule\"\xa8\x01\n\x17\x45ventWithdrawRedemption\x12K\n\x08schedule\x18\x01 \x01(\x0b\x32/.injective.insurance.v1beta1.RedemptionScheduleR\x08schedule\x12@\n\x0bredeem_coin\x18\x02 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00R\nredeemCoin\"\xc3\x01\n\x0f\x45ventUnderwrite\x12 \n\x0bunderwriter\x18\x01 \x01(\tR\x0bunderwriter\x12\x1a\n\x08marketId\x18\x02 \x01(\tR\x08marketId\x12\x39\n\x07\x64\x65posit\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00R\x07\x64\x65posit\x12\x37\n\x06shares\x18\x04 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00R\x06shares\"\x9b\x01\n\x16\x45ventInsuranceWithdraw\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12#\n\rmarket_ticker\x18\x02 \x01(\tR\x0cmarketTicker\x12?\n\nwithdrawal\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00R\nwithdrawalB\x8d\x02\n\x1f\x63om.injective.insurance.v1beta1B\x0b\x45ventsProtoP\x01ZOgithub.com/InjectiveLabs/injective-core/injective-chain/modules/insurance/types\xa2\x02\x03IIX\xaa\x02\x1bInjective.Insurance.V1beta1\xca\x02\x1bInjective\\Insurance\\V1beta1\xe2\x02\'Injective\\Insurance\\V1beta1\\GPBMetadata\xea\x02\x1dInjective::Insurance::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.insurance.v1beta1.events_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\037com.injective.insurance.v1beta1B\013EventsProtoP\001ZOgithub.com/InjectiveLabs/injective-core/injective-chain/modules/insurance/types\242\002\003IIX\252\002\033Injective.Insurance.V1beta1\312\002\033Injective\\Insurance\\V1beta1\342\002\'Injective\\Insurance\\V1beta1\\GPBMetadata\352\002\035Injective::Insurance::V1beta1'
  _globals['_EVENTWITHDRAWREDEMPTION'].fields_by_name['redeem_coin']._loaded_options = None
  _globals['_EVENTWITHDRAWREDEMPTION'].fields_by_name['redeem_coin']._serialized_options = b'\310\336\037\000'
  _globals['_EVENTUNDERWRITE'].fields_by_name['deposit']._loaded_options = None
  _globals['_EVENTUNDERWRITE'].fields_by_name['deposit']._serialized_options = b'\310\336\037\000'
  _globals['_EVENTUNDERWRITE'].fields_by_name['shares']._loaded_options = None
  _globals['_EVENTUNDERWRITE'].fields_by_name['shares']._serialized_options = b'\310\336\037\000'
  _globals['_EVENTINSURANCEWITHDRAW'].fields_by_name['withdrawal']._loaded_options = None
  _globals['_EVENTINSURANCEWITHDRAW'].fields_by_name['withdrawal']._serialized_options = b'\310\336\037\000'
  _globals['_EVENTINSURANCEFUNDUPDATE']._serialized_start=172
  _globals['_EVENTINSURANCEFUNDUPDATE']._serialized_end=262
  _globals['_EVENTREQUESTREDEMPTION']._serialized_start=264
  _globals['_EVENTREQUESTREDEMPTION']._serialized_end=365
  _globals['_EVENTWITHDRAWREDEMPTION']._serialized_start=368
  _globals['_EVENTWITHDRAWREDEMPTION']._serialized_end=536
  _globals['_EVENTUNDERWRITE']._serialized_start=539
  _globals['_EVENTUNDERWRITE']._serialized_end=734
  _globals['_EVENTINSURANCEWITHDRAW']._serialized_start=737
  _globals['_EVENTINSURANCEWITHDRAW']._serialized_end=892
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cometbft/mempool/v2/types.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x63ometbft/mempool/v2/types.proto\x12\x13\x63ometbft.mempool.v2\"\x17\n\x03Txs\x12\x10\n\x03txs\x18\x01 \x03(\x0cR\x03txs\"\x1f\n\x06HaveTx\x12\x15\n\x06tx_key\x18\x01 \x01(\x0cR\x05txKey\"\x0c\n\nResetRoute\"\xba\x01\n\x07Message\x12,\n\x03txs\x18\x01 \x01(\x0b\x32\x18.cometbft.mempool.v2.TxsH\x00R\x03txs\x12\x36\n\x07have_tx\x18\x02 \x01(\x0b\x32\x1b.cometbft.mempool.v2.HaveTxH\x00R\x06haveTx\x12\x42\n\x0breset_route\x18\x03 \x01(\x0b\x32\x1f.cometbft.mempool.v2.ResetRouteH\x00R\nresetRouteB\x05\n\x03sumB\xc9\x01\n\x17\x63om.cometbft.mempool.v2B\nTypesProtoP\x01Z4github.com/cometbft/cometbft/api/cometbft/mempool/v2\xa2\x02\x03\x43MX\xaa\x02\x13\x43ometbft.Mempool.V2\xca\x02\x13\x43ometbft\\Mempool\\V2\xe2\x02\x1f\x43ometbft\\Mempool\\V2\\GPBMetadata\xea\x02\x15\x43ometbft::Mempool::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.mempool.v2.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027com.cometbft.mempool.v2B\nTypesProtoP\001Z4github.com/cometbft/cometbft/api/cometbft/mempool/v2\242\002\003CMX\252\002\023Cometbft.Mempool.V2\312\002\023Cometbft\\Mempool\\V2\342\002\037Cometbft\\Mempool\\V2\\GPBMetadata\352\002\025Cometbft::Mempool::V2'
  _globals['_TXS']._serialized_start=56
  _globals['_TXS']._serialized_end=79
  _globals['_HAVETX']._serialized_start=81
  _globals['_HAVETX']._serialized_end=112
  _globals['_RESETROUTE']._serialized_start=114
  _globals['_RESETROUTE']._serialized_end=126
  _globals['_MESSAGE']._serialized_start=129
  _globals['_MESSAGE']._serialized_end=315
# @@protoc_insertion_point(module_scope)
